@@ -7,15 +7,16 @@ use nc;
 use nix::mount::{MntFlags, MsFlags};
 use nix::sched::CloneFlags;
 use nix::sys::stat::Mode;
-use nix::unistd::{self, close, dup2, setsid, Gid, Uid};
+use nix::unistd::{self, Gid, Uid, close, dup2, setsid};
 use oci_spec::runtime::{
-    IOPriorityClass, LinuxIOPriority, LinuxNamespaceType, LinuxSchedulerFlag, LinuxSchedulerPolicy,
-    Scheduler, Spec, User,
+    IOPriorityClass, LinuxIOPriority, LinuxNamespaceType, LinuxPersonalityDomain,
+    LinuxSchedulerFlag, LinuxSchedulerPolicy, Scheduler, Spec, User,
 };
 
+use super::Result;
 use super::context::InitContext;
 use super::error::InitProcessError;
-use super::Result;
+use crate::config::PersonalityDomain;
 use crate::error::MissingSpecError;
 use crate::namespaces::Namespaces;
 use crate::process::args::{ContainerArgs, ContainerType};
@@ -125,6 +126,26 @@ pub fn container_init_process(
         }
     }
 
+    if let Some(personality) = ctx.linux.personality() {
+        if let Some(flags) = personality.flags() {
+            if !flags.is_empty() {
+                tracing::error!("personality flag has not supported at this time");
+                return Err(InitProcessError::UnsupportedPersonalityFlag);
+            }
+        }
+
+        let domain = match personality.domain() {
+            // https://github.com/opencontainers/runtime-spec/blob/main/config-linux.md#personality
+            LinuxPersonalityDomain::PerLinux => PersonalityDomain::Linux,
+            LinuxPersonalityDomain::PerLinux32 => PersonalityDomain::Linux32,
+        };
+
+        ctx.syscall.personality(domain).map_err(|err| {
+            tracing::error!(?err, "failed to set linux personality ");
+            InitProcessError::SyscallOther(err)
+        })?;
+    }
+
     if let Some(profile) = ctx.process.apparmor_profile() {
         apparmor::apply_profile(profile).map_err(|err| {
             tracing::error!(?err, "failed to apply apparmor profile");
@@ -1116,12 +1137,14 @@ mod tests {
             Err(SyscallError::Nix(nix::errno::Errno::ENOTDIR))
         });
 
-        assert!(masked_path(
-            Path::new("/proc/self"),
-            &Some("default".to_string()),
-            syscall.as_ref()
-        )
-        .is_ok());
+        assert!(
+            masked_path(
+                Path::new("/proc/self"),
+                &Some("default".to_string()),
+                syscall.as_ref()
+            )
+            .is_ok()
+        );
 
         let got = mocks.get_mount_args();
         let want = MountArgs {
