@@ -13,14 +13,15 @@ use std::{fs, mem, ptr};
 use caps::{CapSet, CapsHashSet};
 use libc::{c_char, setdomainname, uid_t};
 use nix::fcntl;
-use nix::fcntl::{open, OFlag};
-use nix::mount::{mount, umount2, MntFlags, MsFlags};
-use nix::sched::{unshare, CloneFlags};
-use nix::sys::stat::{mknod, Mode, SFlag};
-use nix::unistd::{chown, chroot, close, fchdir, pivot_root, sethostname, Gid, Uid};
+use nix::fcntl::{OFlag, open};
+use nix::mount::{MntFlags, MsFlags, mount, umount2};
+use nix::sched::{CloneFlags, unshare};
+use nix::sys::stat::{Mode, SFlag, mknod};
+use nix::unistd::{Gid, Uid, chown, chroot, close, fchdir, pivot_root, sethostname};
 use oci_spec::runtime::PosixRlimit;
 
 use super::{Result, Syscall, SyscallError};
+use crate::config::PersonalityDomain;
 use crate::{capabilities, utils};
 
 // Flags used in mount_setattr(2).
@@ -297,12 +298,12 @@ impl LinuxSyscall {
     where
         T: From<&'a OsStr>,
     {
-        T::from(OsStr::from_bytes(CStr::from_ptr(p).to_bytes()))
+        unsafe { T::from(OsStr::from_bytes(CStr::from_ptr(p).to_bytes())) }
     }
 
     /// Reads data from the `c_passwd` and returns it as a `User`.
     unsafe fn passwd_to_user(passwd: libc::passwd) -> Arc<OsStr> {
-        let name: Arc<OsStr> = Self::from_raw_buf(passwd.pw_name);
+        let name: Arc<OsStr> = unsafe { Self::from_raw_buf(passwd.pw_name) };
         name
     }
 
@@ -350,10 +351,7 @@ impl LinuxSyscall {
                 // Convert the file name from string into i32. Since we are looking
                 // at /proc/<pid>/fd, anything that's not a number (i32) can be
                 // ignored. We are only interested in opened fds.
-                match file_name.parse() {
-                    Ok(fd) => Some(fd),
-                    Err(_) => None,
-                }
+                file_name.parse().ok()
             })
             .collect();
 
@@ -376,9 +374,8 @@ impl Syscall for LinuxSyscall {
             OFlag::O_DIRECTORY | OFlag::O_RDONLY | OFlag::O_CLOEXEC,
             Mode::empty(),
         )
-        .map_err(|errno| {
+        .inspect_err(|errno| {
             tracing::error!(?errno, ?path, "failed to open the new root for pivot root");
-            errno
         })?;
 
         // make the given path as the root directory for the container
@@ -389,9 +386,8 @@ impl Syscall for LinuxSyscall {
         // this path. This is done, as otherwise, we will need to create a separate temporary directory under the new root path
         // so we can move the original root there, and then unmount that. This way saves the creation of the temporary
         // directory to put original root directory.
-        pivot_root(path, path).map_err(|errno| {
+        pivot_root(path, path).inspect_err(|errno| {
             tracing::error!(?errno, ?path, "failed to pivot root to");
-            errno
         })?;
 
         // Make the original root directory rslave to avoid propagating unmount event to the host mount namespace.
@@ -403,28 +399,24 @@ impl Syscall for LinuxSyscall {
             MsFlags::MS_SLAVE | MsFlags::MS_REC,
             None::<&str>,
         )
-        .map_err(|errno| {
+        .inspect_err(|errno| {
             tracing::error!(?errno, "failed to make original root directory rslave");
-            errno
         })?;
 
         // Unmount the original root directory which was stacked on top of new root directory
         // MNT_DETACH makes the mount point unavailable to new accesses, but waits till the original mount point
         // to be free of activity to actually unmount
         // see https://man7.org/linux/man-pages/man2/umount2.2.html for more information
-        umount2("/", MntFlags::MNT_DETACH).map_err(|errno| {
+        umount2("/", MntFlags::MNT_DETACH).inspect_err(|errno| {
             tracing::error!(?errno, "failed to unmount old root directory");
-            errno
         })?;
         // Change directory to the new root
-        fchdir(newroot).map_err(|errno| {
+        fchdir(newroot).inspect_err(|errno| {
             tracing::error!(?errno, ?newroot, "failed to change directory to new root");
-            errno
         })?;
 
-        close(newroot).map_err(|errno| {
+        close(newroot).inspect_err(|errno| {
             tracing::error!(?errno, ?newroot, "failed to close new root directory");
-            errno
         })?;
 
         Ok(())
@@ -743,6 +735,13 @@ impl Syscall for LinuxSyscall {
     fn get_egid(&self) -> Gid {
         nix::unistd::getegid()
     }
+
+    fn personality(&self, domain: PersonalityDomain) -> Result<()> {
+        let domain = nix::sys::personality::Persona::from_bits_retain(domain as i32);
+        nix::sys::personality::set(domain)
+            .map(|_| ())
+            .map_err(|e| e.into())
+    }
 }
 
 #[cfg(test)]
@@ -756,7 +755,7 @@ mod tests {
     use std::os::unix::prelude::AsRawFd;
     use std::str::FromStr;
 
-    use anyhow::{bail, Context, Result};
+    use anyhow::{Context, Result, bail};
     use nix::{fcntl, sys, unistd};
     use serial_test::serial;
 
@@ -770,7 +769,7 @@ mod tests {
         let fd = file.as_raw_fd();
         let open_fds = LinuxSyscall::get_open_fds()?;
 
-        if !open_fds.iter().any(|&v| v == fd) {
+        if !open_fds.contains(&fd) {
             bail!("failed to find the opened dev null fds: {:?}", open_fds);
         }
 
@@ -780,7 +779,7 @@ mod tests {
         // The stdio fds should also be contained in the list of opened fds.
         if ![0, 1, 2]
             .iter()
-            .all(|&stdio_fd| open_fds.iter().any(|&open_fd| open_fd == stdio_fd))
+            .all(|&stdio_fd| open_fds.contains(&stdio_fd))
         {
             bail!("failed to find the stdio fds: {:?}", open_fds);
         }
